# omnicomm

[![GitHub Actions](https://github.com/pikhovkin/omnicomm/actions/workflows/tests.yml/badge.svg)](https://github.com/pikhovkin/omnicomm/actions)
![badge](https://img.shields.io/endpoint?url=https://gist.githubusercontent.com/pikhovkin/c500a58a703c75a80014a92d8bf031f4/raw/covbadge.json)
[![PyPI - Version](https://img.shields.io/pypi/v/omnicomm.svg)](https://pypi.org/project/omnicomm/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/omnicomm.svg)](https://pypi.org/project/omnicomm/)
[![PyPI - License](https://img.shields.io/pypi/l/omnicomm.svg)](./LICENSE)

[![Hatch project](https://img.shields.io/badge/%F0%9F%A5%9A-Hatch-4051b5.svg)](https://github.com/pypa/hatch)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)

Implementation of the Omnicomm protocol.

### Installation

```console
pip install omnicomm
```

### Usage

See `omnicomm/tests`.

## License

MIT
